@@ -5,9 +5,9 @@
 #include "config.h"
 #include "main.h"
 #include "col.h"
-#include "utils.h"
+#include "theme.h"
 
-#define CONF_VER 24
+#define CONF_VER 25
 #define CONFIG_KEY "config"
 
 #define LIM(v, min, max) {if (v >= max) v = max; else if (v <= min) v = min;}
@@ -133,6 +133,8 @@ config_init(void)
      (edd_base, Config, "active_links_url", active_links_url, EET_T_UCHAR);
    EET_DATA_DESCRIPTOR_ADD_BASIC
      (edd_base, Config, "active_links_escape", active_links_escape, EET_T_UCHAR);
+   EET_DATA_DESCRIPTOR_ADD_BASIC
+     (edd_base, Config, "active_links_color", active_links_color, EET_T_UCHAR);
    EET_DATA_DESCRIPTOR_ADD_BASIC
      (edd_base, Config, "translucent", translucent, EET_T_UCHAR);
    EET_DATA_DESCRIPTOR_ADD_BASIC
@@ -296,6 +298,7 @@ config_sync(const Config *config_src, Config *config)
    config->active_links_file = config_src->active_links_file;
    config->active_links_url = config_src->active_links_url;
    config->active_links_escape = config_src->active_links_escape;
+   config->active_links_color = config_src->active_links_color;
    config->mute = config_src->mute;
    config->visualize = config_src->visualize;
    config->urg_bell = config_src->urg_bell;
@@ -563,6 +566,7 @@ config_new(void)
         config->active_links_file = EINA_TRUE;
         config->active_links_url = EINA_TRUE;
         config->active_links_escape = EINA_TRUE;
+        config->active_links_color = EINA_TRUE;
         config->translucent = EINA_FALSE;
         config->mute = EINA_FALSE;
         config->visualize = EINA_TRUE;
@@ -736,7 +740,15 @@ config_load(void)
                   config->group_all = EINA_FALSE;
                   EINA_FALLTHROUGH;
                   /*pass through*/
-                case CONF_VER: /* 24 */
+                case 24:
+                  config->active_links_color = (
+                     config->active_links_email ||
+                     config->active_links_file ||
+                     config->active_links_url ||
+                     config->active_links_escape);
+                  EINA_FALLTHROUGH;
+                  /*pass through*/
+                case CONF_VER: /* 25 */
                   config->version = CONF_VER;
                   break;
                 default:
@@ -814,6 +826,7 @@ config_fork(const Config *config)
    CPY(active_links_file);
    CPY(active_links_url);
    CPY(active_links_escape);
+   CPY(active_links_color);
    CPY(translucent);
    CPY(opacity);
    CPY(mute);
@@ -887,29 +900,3 @@ config_del(Config *config)
    free(config);
 }
 
-const char *
-config_theme_path_get(const Config *config)
-{
-   EINA_SAFETY_ON_NULL_RETURN_VAL(config, NULL);
-   EINA_SAFETY_ON_NULL_RETURN_VAL(config->theme, NULL);
-
-   if (strchr(config->theme, '/'))
-     return config->theme;
-
-   return theme_path_get(config->theme);
-}
-
-const char *
-config_theme_path_default_get(const Config *config)
-{
-   static char path[PATH_MAX] = "";
-
-   EINA_SAFETY_ON_NULL_RETURN_VAL(config, NULL);
-   EINA_SAFETY_ON_NULL_RETURN_VAL(config->theme, NULL);
-
-   if (path[0]) return path;
-
-   snprintf(path, sizeof(path), "%s/themes/default.edj",
-            elm_app_data_dir_get());
-   return path;
-}
