@@ -6,8 +6,8 @@
 #include "config.h"
 #include "termio.h"
 #include "media.h"
-#include "md5/md5.h"
-#include "utils.h"
+#include "md5.h"
+#include "theme.h"
 
 /* specific log domain to help debug the gravatar module */
 int _gravatar_log_dom = -1;
