@@ -13,7 +13,7 @@
 #include "config.h"
 #include "controls.h"
 #include "media.h"
-#include "utils.h"
+#include "theme.h"
 #include "ipc.h"
 #include "sel.h"
 #include "miniview.h"
@@ -545,7 +545,7 @@ _translate_options(void)
 }
 #endif
 
-#if defined(ENABLE_FUZZING) || defined(ENABLE_TESTS)
+#if defined(BINARY_TYFUZZ) || defined(BINARY_TYTEST)
 static void
 _log_void(const Eina_Log_Domain *_d EINA_UNUSED,
           Eina_Log_Level level EINA_UNUSED,
@@ -846,7 +846,7 @@ elm_main(int argc, char **argv)
 
    terminology_starting_up = EINA_TRUE;
 
-#if defined(ENABLE_FUZZING) || defined(ENABLE_TESTS)
+#if defined(BINARY_TYFUZZ) || defined(BINARY_TYTEST)
    eina_log_print_cb_set(_log_void, NULL);
 #endif
 
