@@ -18,8 +18,8 @@ void term_set_title(Term *term);
 void term_miniview_hide(Term *term);
 Eina_Bool term_tab_go(Term *term, int tnum);
 
-void split_horizontally(Evas_Object *win, Evas_Object *term, const char *cmd);
-void split_vertically(Evas_Object *win, Evas_Object *term, const char *cmd);
+void split_horizontally(Evas_Object *term, const char *cmd);
+void split_vertically(Evas_Object *term, const char *cmd);
 
 
 Win *
@@ -40,6 +40,7 @@ int win_term_set(Win *wn, Term *term);
 Eina_List *
 terms_from_win_object(Evas_Object *win);
 
+Win *win_evas_object_to_win(const Evas_Object *win);
 Evas_Object *win_evas_object_get(const Win *win);
 Eina_List * win_terms_get(const Win *wn);
 Config *win_config_get(const Win *wn);
@@ -49,7 +50,8 @@ void win_sizing_handle(Win *wn);
 void win_toggle_visible_group(Win *wn);
 void win_toggle_all_group(Win *wn);
 Eina_Bool win_is_group_action_handled(Win *wn);
-Eina_Bool win_is_group_input(Win *wn);
+Eina_Bool win_is_group_input(const Win *wn);
+Eina_Bool win_has_single_child(const Win *wn);
 void win_scale_wizard(Evas_Object *win, Term *term);
 
 
@@ -70,8 +72,8 @@ void term_right(Term *term);
 Ecore_IMF_Context *
 term_imf_context_get(Term *term);
 
-Eina_Bool term_is_visible(Term *term);
-Eina_Bool term_is_focused(Term *term);
+Eina_Bool term_is_visible(const Term *term);
+Eina_Bool term_is_focused(const Term *term);
 
 void win_font_size_set(Win *wn, int new_size);
 void win_font_update(Term *term);
@@ -90,6 +92,6 @@ void
 term_apply_shine(Term *term, int shine);
 void background_set_shine(Config *config, Evas_Object *bg);
 
-void main_trans_update(const Config *config);
+void main_trans_update(void);
 
 #endif
